# tagesschau
Die Tagesschau ist eine Nachrichtensendung der ARD (Abkürzung für Arbeitsgemeinschaft der öffentlich-rechtlichen Rundfunkanstalten der Bundesrepublik Deutschland), die von ARD-aktuell in Hamburg produziert und mehrmals täglich ausgestrahlt wird. ARD-aktuell ist seit 1977 die zentrale Fernsehnachrichtenredaktion der ARD, bei welcher es sich wiederum um einen Rundfunkverbund handelt, der aus den Landesrundfunkanstalten und der Deutschen Welle besteht.<br>Über die hier dokumentierte API stehen auf [www.tagesschau.de](https://www.tagesschau.de) aktuelle Nachrichten und Medienbeiträge im JSON-Format zur Verfügung.<br>

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.0
- Package version: 0.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

```sh
pip install deutschland[tagesschau]
```

### poetry install

```sh
poetry add deutschland -E tagesschau
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

## Usage

Import the package:
```python
from deutschland import tagesschau
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
from deutschland import tagesschau
from pprint import pprint
from deutschland.tagesschau.api import default_api
from deutschland.tagesschau.model.channels_response import ChannelsResponse
from deutschland.tagesschau.model.homepage_response import HomepageResponse
from deutschland.tagesschau.model.multimedia_response import MultimediaResponse
from deutschland.tagesschau.model.news_response import NewsResponse
from deutschland.tagesschau.model.search_response import SearchResponse
# Defining the host is optional and defaults to https://www.tagesschau.de
# See configuration.py for a list of all supported configuration parameters.
configuration = tagesschau.Configuration(
    host = "https://www.tagesschau.de"
)



# Enter a context with an instance of the API client
with tagesschau.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = default_api.DefaultApi(api_client)

    try:
        # Wichtige Nachrichten und Eilmeldungen
        api_response = api_instance.api2()
        pprint(api_response)
    except tagesschau.ApiException as e:
        print("Exception when calling DefaultApi->api2: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://www.tagesschau.de*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**api2**](docs/DefaultApi.md#api2) | **GET** /api2 | Wichtige Nachrichten und Eilmeldungen
*DefaultApi* | [**channels**](docs/DefaultApi.md#channels) | **GET** /api2/channels | Aktuelle Kanäle
*DefaultApi* | [**homepage**](docs/DefaultApi.md#homepage) | **GET** /api2/homepage | Ausgewählte aktuelle Nachrichten und Eilmeldungen
*DefaultApi* | [**multimedia**](docs/DefaultApi.md#multimedia) | **GET** /api2/multimedia | Multimedia
*DefaultApi* | [**news**](docs/DefaultApi.md#news) | **GET** /api2/news | Aktuelle Nachrichten und Eilmeldungen
*DefaultApi* | [**newsfeed**](docs/DefaultApi.md#newsfeed) | **GET** /api2/newsfeed-101~_date-{datumsangabe}.json | Newsfeed
*DefaultApi* | [**ressort**](docs/DefaultApi.md#ressort) | **GET** /api2/{ressort} | Ressort-spezifische Nachrichten
*DefaultApi* | [**search**](docs/DefaultApi.md#search) | **GET** /api2/search | Suche


## Documentation For Models

 - [ChannelsResponse](docs/ChannelsResponse.md)
 - [ChannelsResponseChannels](docs/ChannelsResponseChannels.md)
 - [HomepageResponse](docs/HomepageResponse.md)
 - [HomepageResponseNews](docs/HomepageResponseNews.md)
 - [HomepageResponseRegional](docs/HomepageResponseRegional.md)
 - [MultimediaResponse](docs/MultimediaResponse.md)
 - [NewsResponse](docs/NewsResponse.md)
 - [NewsResponseNews](docs/NewsResponseNews.md)
 - [SearchResponse](docs/SearchResponse.md)
 - [SearchResponseSearchResults](docs/SearchResponseSearchResults.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

kontakt@bund.dev


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in tagesschau.apis and tagesschau.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from deutschland.tagesschau.api.default_api import DefaultApi`
- `from deutschland.tagesschau.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
from deutschland import tagesschau
from deutschland.tagesschau.apis import *
from deutschland.tagesschau.models import *
```

